@@ -42,8 +42,8 @@ class Worksheet(object):
 
     def cell(self, coordinate=None, row=None, column=None):
         """
-        Return a cell for a coordinate.  Note - openpyxl uses a 0-based row,col system, so row=0, col=0 is cell A1,
-        even though Excel is more of a 1-based system.
+        Return a cell for a coordinate.  Note - as of v2.0, openpyxl uses a 1-based row,col system, so row=1, col=1
+        is cell A1.
         """
         if not coordinate:
             coordinate = self.row_col_to_cell(row, column)
@@ -51,7 +51,7 @@ class Worksheet(object):
             row, column = self.cell_to_row_col(coordinate)
         if coordinate not in self._cells:
             xml = self.wb.xmls[self.id]
-            c = xml.find('{0}sheetData/{0}row[@r="{1}"]/{0}c[@r="{2}"]'.format(SHEET_MAIN_NS, row + 1, coordinate))
+            c = xml.find('{0}sheetData/{0}row[@r="{1}"]/{0}c[@r="{2}"]'.format(SHEET_MAIN_NS, row, coordinate))
             if c is None:
                 raise IndexError('Cell {0} on {1} does not exist'.format(coordinate, self.name))
             else:
@@ -62,7 +62,7 @@ class Worksheet(object):
     def cell_to_row_col(ref):
         """Break an excel cell reference such as A1 into it's row and column components"""
         col_row = CELL_RE.match(ref.upper()).groups()
-        return int(col_row[1]) - 1, Worksheet.col_number(col_row[0])
+        return int(col_row[1]), Worksheet.col_number(col_row[0])
 
     @staticmethod
     def col_name(col):
@@ -83,12 +83,12 @@ class Worksheet(object):
         idx = 0
         for i, l in enumerate(reversed(m.group(0))):
             idx += (ord(l) - 64) * pow(26, i)
-        return idx - 1
+        return idx
 
     @staticmethod
     def row_col_to_cell(row, col):
-        """Translate a row, col a cell reference.  Currently add 1 to keep consistent with openpyxl."""
-        return '{0}{1}'.format(Worksheet.col_name(col+1), row+1)
+        """Translate a row, col a cell reference."""
+        return '{0}{1}'.format(Worksheet.col_name(col), row)
 
     @staticmethod
     def cells_in_range(cell_range, include_2d=True):
